/*
 *  spica_struct_1A.h
 *  
 *  SVN Revision:
 *      $Rev: $
 *      $Author: $
 *      $Date: $
 *
 */

#ifndef SPICA_STRUCT_1A_H
#define SPICA_STRUCT_1A_H

#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#include "fitsio.h"

typedef struct {
	char *instrument;
	int orbit;
	int seq;
	char *obstype;
	char *begins;
	char *ends;
	int naxis1;
	int naxis2;
	int naxis3;
	int DCProc;
	int ENProc;
	int COSProc;
	int SATProc;
	char* File0C;
	int orbDCNU;
	char* data_status;
	char* geo_status;
	char* flag_status;
	char* dc_status;
}Info;

typedef struct {
	int codeop;
	int binning;
	int ht;
	int ti;
	int x0;
	int y0;
	int slit;
	int peltier;
	int uvsampling;
	int iron;
	int soiron;
	int *all_ti;
	float *t_peltier;
	float *t_ccd;
	float *t_numboard;
	float *t_btboard;
	float *t_shutter;
	float *t_servboard;
	float *t_hvps;
	float *t_structure;
}Parameters;

typedef struct {
	char *target;
	float sunlat;
	float sunlong;
	float sundist;
	float sunls;
	float sunra;
	float sundec;
	float slitcenter[2];
	char *shadowcone;
}GeoInfo;

typedef struct {
	int *number;
	char **time;
}Geo_Record;

typedef struct {
	float *lat;
	float *lon;
	float *alt;
	float *sza;
	float *shadowconeratio;
}Geo_Spacecraft;

typedef struct {
	float *sza;
	float *disttoplanetnp;
	float *pixelsize;
	float *anglelossun;
	float *phaselossun;
	float *solarincidence;
	float *solarlocaltime;
	float *anglenormalobserver;
	float *sunazimuth;
	float *distlosplanetcenter;
	float *distscplanetcenter;
	float *lat;
	float *lon;
	float *alt;
	float *ra;
	float *dec;
}Geo_Band3LOSE;

typedef struct {
	float *lat;
	float *lon;
	float *alt;
	float *ra;
	float *dec;
}Geo_BandCCDline;

typedef struct {
	float *xsc_x;
	float *xsc_y;
	float *xsc_z;
	float *ysc_x;
	float *ysc_y;
	float *ysc_z;
	float *zsc_x;
	float *zsc_y;
	float *zsc_z;
	float *angle_xsc_localvert;
	float *angle_xsc_proj;
	float *p1_u;
	float *p1_v;
	float *p2_u;
	float *p2_v;
	float *p3_u;
	float *p3_v;
	float *p4_u;
	float *p4_v;
	float *p5_u;
	float *p5_v;
}Geo_Coordinates;

typedef struct {
	float *x_ra;
	float *x_dec;
	float *y_ra;
	float *y_dec;
	float *z_ra;
	float *z_dec;
} Geo_TransMatrix;

typedef struct {
	Geo_Record Record;
	Geo_Spacecraft Spacecraft;
	Geo_Band3LOSE Band3;
	Geo_Band3LOSE LOSE;
	Geo_BandCCDline Band1;
	Geo_BandCCDline Band2;
	Geo_BandCCDline Band4;
	Geo_BandCCDline Band5;
	Geo_BandCCDline CCDLine;
	Geo_Coordinates Coordinates;
	Geo_TransMatrix TransMatrix;
}Geo;

typedef struct {
	float *cleandata[100];
	float *errdata[100];
	int *flag[100];
	Info Info;
	Parameters Parameters;
	GeoInfo GeoInfo;
	Geo Geo;
} spica_1Afile;


void read_Info(fitsfile *,spica_1Afile*,int);
void read_Data(fitsfile *,spica_1Afile*,int);
void read_ErrData(fitsfile *,spica_1Afile*,int);
void read_Flag(fitsfile *,spica_1Afile*,int);
void read_Parameters(fitsfile *,spica_1Afile*,int);
void read_GeoInfo(fitsfile *,spica_1Afile*,int);
void read_Geo(fitsfile *,spica_1Afile*,int);
char *trimchars(char *);
void spica_struct_1A(spica_1Afile*,char*,int);

#endif SPICA_STRUCT_1A_H		/* SPICA_STRUCT_1A_H */
